/*
  Antenna House PDF Tool API V7.0
  Java Interface sample program

  概要：指定した画像の角度を変えて描画する

  Copyright (C) 2023- Antenna House, Inc. All rights reserved.
  Antenna House is a trademark of [Antenna House, Inc.]

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

package cookbook;

import jp.co.antenna.ptl.*;


public class AddImageSetAngle {

    // そのクラスのusageを表示する関数
    private static void printUsage() {
            System.out.println("usage: java AddImageSetAngle in-pdf-file out-pdf-file insert-image-file"
                             + " angle");
            System.out.println("angle : 画像の角度");
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 4) {
            printUsage();
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument()) {
            // PDFファイルをロードします
            doc.load(inputFile);
            
            //コマンドライン引数の取得
            float angle = Float.parseFloat(args[3]);

            try (PtlPages pages = doc.getPages()) { // ページコンテナの取得
                // ページコンテナが空かどうか
                if (pages.isEmpty()) {
                    System.out.println("ページコンテナが空");
                    return;
                }
                
                try (PtlPage page = pages.get(0);// 先頭ページの取得(パラメータindexは0が先頭)
                     PtlContent content = page.getContent();// ページコンテントの取得
                     PtlRect outputRect = page.getViewBox(); // 出力矩形の設定。(ページの大きさを得るためにViewBoxを取得する)
                     PtlParamDrawImage paramDrawImage = new PtlParamDrawImage(); //画像の描画に使うパラメータクラス
                     PtlParamInput insertImage = new PtlParamInput(args[2]); //画像指定に使うパラメータクラス
                     PtlParamWriteString plainParam = new PtlParamWriteString()) {// 文字描画のパラメータクラス。
                    //入力画像の角度を設定
                    paramDrawImage.setAngle(angle);
                    
                    //入力画像ストリームの設定
                    paramDrawImage.setImageStream(insertImage);
                    //マルチTiffのページ番号の設定（マルチTiffファイルにのみ有効） 
                    //数値を設定しない場合は、-1が設定されたとみなします
                    //PtlParamImagePageに設定する場合に限り、-1を設定すると全ページを挿入します。
                    paramDrawImage.setImagePageNumber(0);

                    // 透明度を設定
                    paramDrawImage.setOpacity(1);
                    // 画像出力
                    content.drawImage(outputRect, PtlContent.ALIGN.ALIGN_CENTER, paramDrawImage);
                    // angleの状態テキストを描画
                    content.writeString(outputRect, PtlContent.ALIGN.ALIGN_CENTER, "angle = " + angle, plainParam);
                }
                catch (IllegalArgumentException ex) {//PtlContent.ALIGN指定のエラー処理
                    System.out.println(ex.getMessage());
                    System.out.println("ERROR : alignにはPtlContent.ALIGNに含まれる名前を指定してください。");
                    ex.printStackTrace();
                }
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() +
                               "\n  " + pex.getErrorMessage());
        }
        catch (Exception | Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}