/*
  Antenna House PDF Tool API V7.0
  Java Interface sample program

  概要：作成日時・更新日時の有効性を確認しながら取得します。

  Copyright (C) 2023- Antenna House, Inc. All rights reserved.
  Antenna House is a trademark of [Antenna House, Inc.]

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

package cookbook;

import jp.co.antenna.ptl.*;

public class GetDocInfoWithValidationDate {

    // そのクラスのusageを表示する関数
    private static void printUsage() {
        System.out.println("usage: java GetDocInfoWithValidationDate in-pdf-file");
     }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 1) {
            printUsage();
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlPDFDocument doc = new PtlPDFDocument()) {
            // PDFファイルをロード
            doc.load(inputFile);

            try (PtlDocProperty docProperty = doc.getDocProperty(); //PDFの文書プロパティ
                 PtlDocInfo docinf = docProperty.getDocInfo()) {    //PDFの文書情報
                // 作成日付を取得
                try (PtlDate dateCreate = docinf.getCreationDate()) {
                    if(dateCreate.isValid()){ //CreationDateの有効性チェック
                        System.out.println("CreationDate : "
                            + dateCreate.getYear()
                            + "/" + dateCreate.getMonth()
                            + "/" + dateCreate.getDay()
                            + " " + dateCreate.getHour()
                            + ":" + dateCreate.getMin()
                            + ":" + dateCreate.getSec());
                    }else{
                        System.out.println("このPDFは有効なCreationDateを持っていません");
                    }
                }

                // 更新日付を取得
                try (PtlDate dateMod = docinf.getModDate()) {
                    if(dateMod.isValid()){
                        System.out.println("ModDate : "
                            + dateMod.getYear()
                            + "/" + dateMod.getMonth()
                            + "/" + dateMod.getDay()
                            + " " + dateMod.getHour()
                            + ":" + dateMod.getMin()
                            + ":" + dateMod.getSec());
                    }else{
                        System.out.println("このPDFは有効なModDateを持っていません。");
                    }
                }
            }
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() +
                               "\n  " + pex.getErrorMessage());
        }
        catch (Exception | Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}